@@ -1,7 +1,7 @@
 /*
  * This file is part of budgie-desktop
  *
- * Copyright © 2015-2022 Budgie Desktop Developers
+ * Copyright Budgie Desktop Developers
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -17,6 +17,8 @@
  */
 const char* BUDGIE_MODULE_DIRECTORY = MODULEDIR;
 const char* BUDGIE_MODULE_DATA_DIRECTORY = MODULE_DATA_DIR;
+const char* BUDGIE_RAVEN_PLUGIN_LIBDIR = RAVEN_PLUGIN_LIBDIR;
+const char* BUDGIE_RAVEN_PLUGIN_DATADIR = RAVEN_PLUGIN_DATADIR;
 const char* BUDGIE_DATADIR = DATADIR;
 const char* BUDGIE_VERSION = PACKAGE_VERSION;
 const char* BUDGIE_WEBSITE = PACKAGE_URL;
